### Name: SETGEN.generate.sets
### Title: Function to create sets of correlated variables (genes)
### Aliases: SETGEN.generate.sets
### Keywords: htest multivariate cluster

### ** Examples

# generate data with two subsets coming
# from one-factor models
set.seed(100)
y <- c(rep(0, 10), rep(1,10))
mu2 <- 0.5  # difference between the means of the two groups of samples
f1 <- matrix(rep(c(rnorm(10), rnorm(10, mean = mu2)), 10), ncol = 10)
f2 <- matrix( rep(c(rnorm(5), rnorm(5, mean = mu2), rnorm(5), rnorm(5, mean = mu2)), 10), ncol = 10 )
x <- matrix(rnorm(20*100), nrow=20)
x[,1:10] <- x[,1:10] + f1
x[,11:20] <- x[,11:20] + f2  
colnames(x) <- paste("v",1:100, sep="")

# looking for significant single variables (e.g., differentially expressed genes)
res1 <- SETGEN(x = x, y = y, resp.type = "Two class unpaired", pivdom = FALSE, r2min = 1, nres = 1000)
res1$overview[1:10,]

# looking for significant sets of correlated variables (genes)
res2 <- SETGEN(x = x, y = y, resp.type = "Two class unpaired", pivdom = FALSE, r2min = 0.5, nres = 1000)
res2$overview[1:10,]

# the same using SETGEN.generate.sets first
genesets <- SETGEN.generate.sets(X1 = x, r2min1 = 0.5, pivdom = FALSE)
res3 <- SETGEN(x = x, y = y, grpdata = genesets, resp.type = "Two class unpaired", nres = 1000)
res3$overview[1:10,]



